# pyQuASAR_genotype
Command line tool for genotyping with QuASAR. Infer genotypes from ChIP-seq or
ATAC-seq data.

## Installation

First, follow the installation steps for [pyQuASAR](https://github.com/anthony-aylward/pyQuASAR) and [wasp_map](https://github.com/anthony-aylward/wasp_map). Then:

```sh
pip3 install pyQuASAR_genotype
```
or
```sh
pip3 install --user pyQuASAR_genotype
```
